﻿package
{
	import flash.display.*;
	import flash.events.*;
	import flash.filters.*;
	import flash.geom.*;
	import flash.utils.*;
	import org.papervision3d.cameras.*;
	import org.papervision3d.view.*;
	import org.papervision3d.materials.*;
	import org.papervision3d.objects.*;
	import org.papervision3d.objects.primitives.*
	import caurina.transitions.*;

	public class World extends BasicView
	{
		static private const FOCUS_POS :int = 1000;
		static private const TIMER_INTERVAL :int = 3;
		
		// 細切れになった写真の3Dパーツを保存する配列です
		private var planeArr:Array /* type of Plane */ = [];
		private var showIndex:uint = 0
		
		public function World ()
		{
			// BasicViewの初期化します
			super(0, 0, true, false, CameraType.FREE);
			
			camera.focus = 500
			camera.zoom = 1
		}
			
		public function init(loaders:Array):void
		{
			trace("world init")
			trace("loaders.length",loaders.length)
			for (var i:int = 0; i < loaders.length; i++ )
			{
				var material:BitmapMaterial = new BitmapMaterial(Bitmap(Loader(loaders[i]).content).bitmapData, false);
				material.doubleSided = true;
				
				var plane:Plane = new Plane(material, 360, 480, 4, 4)
				plane.useOwnContainer = true
				
				plane.x = Math.random() * 3000
				plane.z = Math.random() * 3000
				plane.y = Math.random() * 3000
				plane.rotationX = Math.random() * 360
				plane.rotationY = Math.random() * 360
				plane.rotationZ = Math.random() * 360
				
				planeArr.push(scene.addChild(plane))
			}
			
			var timer:Timer = new Timer(TIMER_INTERVAL * 1000)
			timer.addEventListener(TimerEvent.TIMER, motion)
			timer.start()
			motion()
			
			startRendering()
		}
		
		/**
		 * モーションのメソッドです
		 * @param	event
		 */
		private function motion(event:TimerEvent = null):void
		{
			var old:DisplayObject3D = planeArr[showIndex]
			
			showIndex = (showIndex == planeArr.length - 1) ? 0 : showIndex + 1
			
			var tgt:DisplayObject3D = planeArr[showIndex]
			var cam:DisplayObject3D = new DisplayObject3D()
			cam.copyTransform(tgt)
			cam.moveBackward(FOCUS_POS)
			
			Tweener.addTween(camera,
			{
				x:cam.x, y:cam.y, z:cam.z,
				rotationX:tgt.rotationX,
				rotationY:tgt.rotationY,
				rotationZ:tgt.rotationZ,
				time       : TIMER_INTERVAL,
				transition : "easeInOutExpo"
			});
		}
		
		override protected function onRenderTick(e:Event = null):void
		{
			// 被写界深度フィルターの適用
			for (var i:int = 0; i < planeArr.length; i++)
			{
				var o:DisplayObject3D = planeArr[i] as DisplayObject3D;
				
				// 距離の算出
				var deg:Number = Math.abs(calcPointDistanceFromCamera(o) - FOCUS_POS);
				
				// ぼかしの適用値
				var blurVal:int = Math.min(32, deg * .02 << 1 );
				var blurFilter:BlurFilter = new BlurFilter(blurVal, blurVal, 1);
				
				// 明度の適用値
				var blightness:Number = deg / 8;
				var blightnessArr:Array =
				[
					1, 0, 0, 0, blightness,
					0, 1, 0, 0, blightness,
					0, 0, 1, 0, blightness,
					0, 0, 0, 1, 0
				];
				var blightnessFilter:ColorMatrixFilter = new ColorMatrixFilter(blightnessArr);
				
				// フィルター適用
				o.filters = [blurFilter, blightnessFilter];
			}
			super.onRenderTick(e)
		}
		
		/**
		* カメラからの距離を算出します
		* @param	obj 計測したいオブジェクト
		* @return	カメラからの距離(3D空間内のpx値)
		*/
		private function calcPointDistanceFromCamera(obj:DisplayObject3D):Number
		{
			var vecX:Number = obj.sceneX - camera.x;
			var vecY:Number = obj.sceneY - camera.y;
			var vecZ:Number = obj.sceneZ - camera.z;
			return Math.sqrt(
				(vecX * vecX)
				+ (vecY * vecY)
				+ (vecZ * vecZ));
		}

	}
}